@@ -31,16 +31,16 @@ public class RTileController extends TileController{
 			map = new HashMap<String,RTileController>();
 			sources = new TileSource[] { 
 	        		new OsmTileSource.Mapnik(),
-	        		new OsmTileSource.MapnikBw(),
-	        		new OsmTileSource.MapToolKitTopo(),
-	        		new OsmTileSource.Waze(),
+	        		//new OsmTileSource.MapnikBw(),
+	        		//new OsmTileSource.MapToolKitTopo(),
+	        		//new OsmTileSource.Waze(),
 	                new BingAerialTileSource(),
 	        		new StamenTileSource.Toner(),
 	        		new StamenTileSource.Terrain(),
 	        		new StamenTileSource.WaterColor(),
 	        		new OsmTileSource.MapnikGerman(),
-	        		new OsmTileSource.Wanderreitkarte(),
-	        		new OsmTileSource.MapBox(),
+	        		//new OsmTileSource.Wanderreitkarte(),
+	        		//new OsmTileSource.MapBox(),
 	        		new OsmTileSource.Esri(),
 	        		new OsmTileSource.EsriTopo(),
 	        		new OsmTileSource.Nps(),
